@@ -11,16 +11,25 @@ use Log::Handler ;
 
 =head1 NAME
 
-Pg::BulkCopy - Bulk Data Load/ Dump for Postgres.
+Pg::BulkCopy - Deprecated use https://github.com/ossc-db/pg_bulkload/
 
 =head1 VERSION
 
-Version 0.21
+Version 0.22
+
+=head1 Deprecated
+
+Back in 2010 when I wrote Pg::BulkCopy I couldn't find a functional bulk load utility for Postgres.
+At this time I think that pg_bulkload is a much better utility for this. 
+
+I've written a short article on installing it at my personal blog 
+L<techinfo.brainbuz.org/?p=429|http://techinfo.brainbuz.org/?p=429>, 
+which will help you get started. 
 
 =cut
 
 package Pg::BulkCopy;
-our $VERSION = '0.21' ;
+our $VERSION = '0.22' ;
 use Moose ;
 	has 'dbistring' => ( isa => 'Str', is => 'rw', required => 1, ) ;
 	has 'filename' => ( isa => 'Str', is => 'rw', required => 1, ) ;	
